==> zio-aws-rds_2.12-5.17.152.1-sources.jar: zio/aws/rds/model/DeleteDbInstanceAutomatedBackupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteDbInstanceAutomatedBackupResponse(
    dbInstanceAutomatedBackup: scala.Option[
      zio.aws.rds.model.DBInstanceAutomatedBackup
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse = {
    import DeleteDbInstanceAutomatedBackupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
      .builder()
      .optionallyWith(
        dbInstanceAutomatedBackup.map(value => value.buildAwsValue())
      )(_.dbInstanceAutomatedBackup)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly =
    zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse
      .wrap(buildAwsValue())
}
object DeleteDbInstanceAutomatedBackupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse =
      zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse(
        dbInstanceAutomatedBackup.map(value => value.asEditable)
      )
    def dbInstanceAutomatedBackup
        : scala.Option[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]
    def getDbInstanceAutomatedBackup: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackup",
      dbInstanceAutomatedBackup
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ) extends zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly {
    override val dbInstanceAutomatedBackup
        : scala.Option[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly] =
      scala
        .Option(impl.dbInstanceAutomatedBackup())
        .map(value => zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ): zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_2.13-5.19.33.1-sources.jar: zio/aws/rds/model/DeleteDbInstanceAutomatedBackupResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteDbInstanceAutomatedBackupResponse(
    dbInstanceAutomatedBackup: Optional[
      zio.aws.rds.model.DBInstanceAutomatedBackup
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse = {
    import DeleteDbInstanceAutomatedBackupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
      .builder()
      .optionallyWith(
        dbInstanceAutomatedBackup.map(value => value.buildAwsValue())
      )(_.dbInstanceAutomatedBackup)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly =
    zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse
      .wrap(buildAwsValue())
}
object DeleteDbInstanceAutomatedBackupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse =
      zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse(
        dbInstanceAutomatedBackup.map(value => value.asEditable)
      )
    def dbInstanceAutomatedBackup
        : Optional[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly]
    def getDbInstanceAutomatedBackup: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbInstanceAutomatedBackup",
      dbInstanceAutomatedBackup
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ) extends zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly {
    override val dbInstanceAutomatedBackup
        : Optional[zio.aws.rds.model.DBInstanceAutomatedBackup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbInstanceAutomatedBackup())
        .map(value => zio.aws.rds.model.DBInstanceAutomatedBackup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbInstanceAutomatedBackupResponse
  ): zio.aws.rds.model.DeleteDbInstanceAutomatedBackupResponse.ReadOnly =
    new Wrapper(impl)
}
